"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getS3Object = void 0;
var _utils = require("../utils");
var _loaders = _interopRequireDefault(require("../transform/loaders"));
const MAX_RETURN_CONTENT_LENGTH = 5000000; // ~4.77MB

const getS3Object = async (fileInfo, s3, context) => {
  const {
    filename,
    options,
    extension
  } = fileInfo;
  const params = (0, _utils.getObjectParams)(filename);
  const objectHead = await s3.headObject(params).promise();
  const contentLength = objectHead.ContentLength ? objectHead.ContentLength : 0;
  for (const loader of _loaders.default) {
    const canProcess = loader.canProcess({
      context,
      s3,
      options,
      file: {
        name: filename,
        extension,
        contentLength
      }
    });
    if (!canProcess) {
      continue;
    }
    return loader.process({
      context,
      s3,
      options,
      file: {
        name: filename,
        extension,
        contentLength
      }
    });
  }

  // If no processors handled the file request, just return the S3 object taking its size into consideration.
  let object;
  if (contentLength < MAX_RETURN_CONTENT_LENGTH) {
    object = await s3.getObject(params).promise();
  }
  return {
    object,
    params
  };
};
exports.getS3Object = getS3Object;