"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
var _exportNames = {
  createFileManagerContext: true,
  createFileManagerGraphQL: true
};
exports.createFileManagerGraphQL = exports.createFileManagerContext = void 0;
var _error = _interopRequireDefault(require("@webiny/error"));
var _api = require("@webiny/api");
var _createFileManager = require("./createFileManager");
var _graphql = require("./graphql");
var _FileStorage = require("./storage/FileStorage");
var _plugins = require("./plugins");
Object.keys(_plugins).forEach(function (key) {
  if (key === "default" || key === "__esModule") return;
  if (Object.prototype.hasOwnProperty.call(_exportNames, key)) return;
  if (key in exports && exports[key] === _plugins[key]) return;
  Object.defineProperty(exports, key, {
    enumerable: true,
    get: function () {
      return _plugins[key];
    }
  });
});
const createFileManagerContext = config => {
  return new _api.ContextPlugin(async context => {
    const getLocaleCode = () => {
      const locale = context.i18n.getContentLocale();
      if (!locale) {
        throw new _error.default("Missing locale on context.i18n locale in File Manager API.", "LOCALE_ERROR");
      }
      return locale.code;
    };
    const getIdentity = () => {
      return context.security.getIdentity();
    };
    const getTenantId = () => {
      return context.tenancy.getCurrentTenant().id;
    };
    const getPermission = async name => {
      await context.i18n.checkI18NContentPermission();
      return context.security.getPermission(name);
    };
    if (config.storageOperations.beforeInit) {
      await config.storageOperations.beforeInit(context);
    }
    context.fileManager = (0, _createFileManager.createFileManager)({
      storageOperations: config.storageOperations,
      getTenantId,
      getLocaleCode,
      getIdentity,
      getPermission,
      storage: new _FileStorage.FileStorage({
        context
      }),
      WEBINY_VERSION: context.WEBINY_VERSION
    });
  });
};
exports.createFileManagerContext = createFileManagerContext;
const createFileManagerGraphQL = () => {
  return (0, _graphql.createGraphQLSchemaPlugin)();
};
exports.createFileManagerGraphQL = createFileManagerGraphQL;